

% CI01 - OCTAL CURRENT MONITOR 1.1.1


% Class CI01
classdef CI01 < Device

   % Public static Constants
   properties (Constant)

      % Channels
      CHANNELS = 8;

      % Sampling Frequencies [Hz]
      FREQUENCY_6 = 6;
      FREQUENCY_12 = 12;
      FREQUENCY_25 = 25;
      FREQUENCY_50 = 50;
      FREQUENCY_100 = 100;
      FREQUENCY_200 = 200;
      FREQUENCY_400 = 400;
      FREQUENCY_800 = 800;
      FREQUENCY_1500 = 1500;
      FREQUENCY_3000 = 3000;

   end


   % Public Member Methods
   methods

      % Constructor
      function this = CI01(address)

         % Initialize
         this = this@Device(address);

      end


      % Set Frequency [Hz]
      function frequency(this, frequency)

         % Control
         code = calllib('device', 'ci01_set_frequency', this.address_, frequency);

         % Error Handler
         this.error_(code);

      end


      % Measure Current [A]
      function current = measure(this, varargin)

         % Check Parameters
         if nargin == 1

            % Set Channel List, Samples, Frequency
            channel = 1 : this.CHANNELS;
            samples = 1;
            frequency = 0;

         elseif nargin == 2

            % Set Channel List, Samples, Frequency
            channel = varargin{1};
            samples = 1;
            frequency = 0;

         elseif nargin == 4

            % Set Channel List, Samples, Frequency
            channel = varargin{1};
            samples = varargin{2};
            frequency = varargin{3};

            % Check Samples
            if (1000000 < samples)

               % Error Handler
               this.error_(this.ERROR_PARAMETER_);

            end

         else

            % Error Handler
            this.error_(this.ERROR_PARAMETER_);

         end

         % Measure Current
         [code, channel, current] = calllib('device', 'ci01_measure', this.address_, channel, numel(channel), ...
             samples, frequency, zeros(1, numel(channel) * samples), numel(channel) * samples);

         % Error Handler
         this.error_(code);

         % Return Current
         current = reshape(current, numel(channel), samples);

      end


      % Stop
      function stop(this)

         % Stop
         code = calllib('device', 'ci01_stop', this.address_);

         % Error Handler
         this.error_(code);

      end

   end

end
