

% CNT01 - QUAD QUADRATURE ENCODER 1.5.0


% Class CNT01
classdef CNT01 < Device

   % Public static Constants
   properties (Constant)

      % Channels
      CHANNELS = 4;

      % Modes
      MODE_NORMAL = 0;
      MODE_QUADRATURE_1X = 1;
      MODE_QUADRATURE_2X = 2;
      MODE_QUADRATURE_4X = 3;

   end


   % Public Member Methods
   methods

      % Constructor
      function this = CNT01(address)

         % Initialize
         this = this@Device(address);

      end


      % Clear
      function clear(this, channel)

         % Check Parameters
         if nargin == 1

            % Set Channel List
            channel = 1 : this.CHANNELS;

         end

         % Clear
         code = calllib('device', 'cnt01_clear', this.address_, channel, numel(channel));

         % Error Handler
         this.error_(code);

      end


      % Disable
      function disable(this, channel)

         % Check Parameters
         if nargin == 1

            % Set Channel List
            channel = 1 : this.CHANNELS;

         end

         % Disable
         code = calllib('device', 'cnt01_disable', this.address_, channel, numel(channel));

         % Error Handler
         this.error_(code);

      end


      % Enable
      function enable(this, channel)

         % Check Parameters
         if nargin == 1

            % Set Channel List
            channel = 1 : this.CHANNELS;

         end

         % Enable
         code = calllib('device', 'cnt01_enable', this.address_, channel, numel(channel));

         % Error Handler
         this.error_(code);

      end


      % Set Mode
      function mode(this, varargin)

         % Check Parameters
         if nargin == 2

            % Set Channel List and Mode List
            channel = 1 : this.CHANNELS;
            mode = repmat(varargin{1}, 1, 4);

         elseif nargin == 3

            % Set Channel and Mode
            channel = varargin{1};
            mode = varargin{2};

            % Check Parameter
            if isscalar(mode)

               % Set Mode List
               mode = repmat(mode, 1, numel(channel));

            end

         else

            % Error Handler
            this.error_(this.ERROR_PARAMETER_);

         end

         % Set Mode
         code = calllib('device', 'cnt01_set_mode', this.address_, channel, numel(channel), mode, numel(mode));

         % Error Handler
         this.error_(code);

      end


      % Read
      function [value, time] = read(this, channel)

         % Check Parameters
         if nargin == 1

            % Set Channel List
            channel = 1 : this.CHANNELS;

         end

         % Read
         [code, ~, value, ~, time] = calllib('device', 'cnt01_read', this.address_, channel, numel(channel), ...
             zeros(1, numel(channel)), numel(channel), 0);

         % Error Handler
         this.error_(code);

      end

   end

end
