

% DO01 - OCTAL DIGITAL OUTPUT BUFFER 1.2.1


% Class DO01
classdef DO01 < Device

   % Public static Constants
   properties (Constant)

      % Channels
      CHANNELS = 8;

   end


   % Public Member Methods
   methods

      % Constructor
      function this = DO01(address)

         % Initialize
         this = this@Device(address);

      end


      % Measure Current [A]
      function current = measure(this, channel)

         % Check Parameters
         if nargin == 1

            % Set Channel List
            channel = 1 : this.CHANNELS;

         end

         % Measure Current
         [code, ~, current] = calllib('device', 'do01_measure', this.address_, channel, numel(channel), ...
             zeros(1, numel(channel)), numel(channel));

         % Error Handler
         this.error_(code);

      end


      % Write
      function write(this, varargin)

         % Check Parameters
         if nargin == 2

            % Set Channel List and State List
            channel = 1 : this.CHANNELS;
            state = repmat(varargin{1}, 1, this.CHANNELS);

         elseif nargin == 3

            % Set Channel and State
            channel = varargin{1};
            state = varargin{2};

            % Check Parameter
            if isscalar(state)

               % Set State List
               state = repmat(state, 1, numel(channel));

            end

         else

            % Error Handler
            this.error_(this.ERROR_PARAMETER_);

         end

         % Write
         code = calllib('device', 'do01_write', this.address_, channel, numel(channel), state, numel(state));

         % Error Handler
         this.error_(code);

      end

   end

end
