

% TMP01 - OCTAL THERMOCOUPLE MONITOR 1.2.2


% Class TMP01
classdef TMP01 < Device

   % Public static Constants
   properties (Constant)

      % Channels
      CHANNELS = 8;

      % Sampling Frequencies [Hz]
      FREQUENCY_6 = 6;
      FREQUENCY_12 = 12;
      FREQUENCY_25 = 25;
      FREQUENCY_50 = 50;
      FREQUENCY_100 = 100;
      FREQUENCY_200 = 200;
      FREQUENCY_400 = 400;
      FREQUENCY_800 = 800;
      FREQUENCY_1500 = 1500;
      FREQUENCY_3000 = 3000;

   end


   % Public Member Methods
   methods

      % Constructor
      function this = TMP01(address)

         % Initialize
         this = this@Device(address);

      end


      % Set Frequency [Hz]
      function frequency(this, frequency)

         % Control
         code = calllib('device', 'tmp01_set_frequency', this.address_, frequency);

         % Error Handler
         this.error_(code);

      end


      % Measure Temperature [K]
      function temperature = measure(this, channel)

         % Check Parameters
         if nargin == 1

            % Set Channel List
            channel = 1 : this.CHANNELS;

         end

         % Measure Temperature
         [code, ~, temperature] = calllib('device', 'tmp01_measure', this.address_, channel, numel(channel), ...
             zeros(1, numel(channel)), numel(channel));

         % Error Handler
         this.error_(code);

      end


      % Set Sensor
      function sensor(this, varargin)

         % Check Parameters
         if nargin == 2

            % Set Channel List and Sensor List
            channel = 1 : this.CHANNELS;
            sensor = repmat(varargin{1}, 1, this.CHANNELS);

         elseif nargin == 3

            % Set Channel and Sensor
            channel = varargin{1};
            sensor = varargin{2};

            % Check Parameter
            if isscalar(sensor)

               % Set Sensor List
               sensor = repmat(sensor, 1, numel(channel));

            end

         else

            % Error Handler
            this.error_(this.ERROR_PARAMETER_);

         end

         % Parse Sensor List
         for i = 1 : numel(sensor)

            % Update Type List
            type(i) = sensor(i).type();

         end

         % Set Sensor
         code = calllib('device', 'tmp01_set_sensor', this.address_, channel, numel(channel), type, numel(type));

         % Error Handler
         this.error_(code);

      end

   end

end
