

// DEVICE DRIVER


// Standard Integers
typedef signed char int8_t;
typedef signed short int16_t;
typedef signed int int32_t;
typedef signed long long int64_t;
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
typedef unsigned int uint32_t;
typedef unsigned long long uint64_t;


// Burn Tag
uint8_t burn(uint32_t address, const char* tag, uint32_t tag_length);

// Configure Device
uint8_t configure(uint32_t serial, const char* name, uint32_t name_length, uint8_t dhcp, uint32_t ip_host,
   uint32_t ip_subnet_mask, uint32_t ip_gateway);

// Find Devices in Subnet
uint8_t find(uint32_t* address, uint16_t* address_size, const uint32_t* serial, uint16_t serial_size);

// Get Driver Info
uint8_t get_driver(char* manufacturer, uint32_t* manufacturer_length, char* version, uint32_t* version_length,
   uint32_t* release);

// Get Device Info
uint8_t get_info(uint32_t address, char* model, uint32_t* model_length, char* description,
   uint32_t* description_length, char* manufacturer, uint32_t* manufacturer_length, uint32_t* serial, char* revision,
   uint32_t* revision_length, char* cpu, uint32_t* cpu_length, uint32_t* frequency, uint32_t* memory, char* network,
   uint32_t* network_length, char* version, uint32_t* version_length, uint32_t* release, uint32_t* calibration,
   uint32_t* expiration, uint32_t* uptime_reset, uint32_t* uptime_total, uint32_t* cycles, uint8_t* eth_host,
   uint32_t* ip_host, uint32_t* ip_subnet_mask, uint32_t* ip_gateway, uint8_t* dhcp, char* hostname,
   uint32_t* hostname_length, char* domain, uint32_t* domain_length, char* name, uint32_t* name_length, char* tag,
   uint32_t* tag_length);

// Get Device Status
uint8_t get_status(uint32_t address, char* symbol, uint32_t* symbol_length, char* description,
   uint32_t* description_length, char* unit, uint32_t* unit_length, float* typical, float* min, float* max,
   float* value, uint32_t* size, uint8_t* ok);

// Get Timeout [ms]
uint8_t get_timeout(uint32_t address, uint16_t* timeout);

// Reset Device
uint8_t reset(uint32_t address);

// Set Timeout [ms]
uint8_t set_timeout(uint32_t address, uint16_t timeout);

// Measure Current [A]
uint8_t ci01_measure(uint32_t address, const uint8_t* channel, uint8_t channel_size, uint32_t samples, float frequency,
   float* current, uint32_t* current_size);

// Set Sampling Frequency [Hz]
uint8_t ci01_set_frequency(uint32_t address, uint16_t frequency);

// Stop Current Measurement or Calibration
uint8_t ci01_stop(uint32_t address);

// Clear Counter
uint8_t cnt01_clear(uint32_t address, const uint8_t* channel, uint8_t channel_size);

// Disable Counter
uint8_t cnt01_disable(uint32_t address, const uint8_t* channel, uint8_t channel_size);

// Enable Counter
uint8_t cnt01_enable(uint32_t address, const uint8_t* channel, uint8_t channel_size);

// Read Counter Value
uint8_t cnt01_read(uint32_t address, const uint8_t* channel, uint8_t channel_size, int64_t* value, uint8_t* value_size,
   uint64_t* time);

// Set Mode
uint8_t cnt01_set_mode(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* mode,
   uint8_t mode_size);

// Read
uint8_t dio01_read(uint32_t address, const uint8_t* channel, uint8_t channel_size, uint8_t* state, uint8_t* state_size);

// Set Direction
uint8_t dio01_set_direction(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* direction,
   uint8_t direction_size);

// Write
uint8_t dio01_write(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* state,
   uint8_t state_size);

// Read
uint8_t dio02_read(uint32_t address, const uint8_t* channel, uint8_t channel_size, uint8_t* state, uint8_t* state_size);

// Set Direction
uint8_t dio02_set_direction(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* direction,
   uint8_t direction_size);

// Write
uint8_t dio02_write(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* state,
   uint8_t state_size);

// Measure Current [A]
uint8_t do01_measure(uint32_t address, const uint8_t* channel, uint8_t channel_size, float* current,
   uint8_t* current_size);

// Write
uint8_t do01_write(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* state,
   uint8_t state_size);

// Write
uint8_t do02_write(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* state,
   uint8_t state_size);

// Measure Temperature [K]
uint8_t tmp01_measure(uint32_t address, const uint8_t* channel, uint8_t channel_size, float* temperature,
   uint8_t* temperature_size);

// Set Sampling Frequency [Hz]
uint8_t tmp01_set_frequency(uint32_t address, uint16_t frequency);

// Set Sensor
uint8_t tmp01_set_sensor(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* type,
   uint8_t type_size);

// Measure Temperature [K]
uint8_t tmp02_measure(uint32_t address, const uint8_t* channel, uint8_t channel_size, float* temperature,
   uint8_t* temperature_size);

// Set Sampling Frequency [Hz]
uint8_t tmp02_set_frequency(uint32_t address, uint16_t frequency);

// Set Sensor
uint8_t tmp02_set_sensor(uint32_t address, const uint8_t* channel, uint8_t channel_size, const uint8_t* type,
   uint8_t type_size, const float* voltage, uint8_t voltage_size, const float* current, uint8_t current_size,
   const float* resistance, uint8_t resistance_size);

// Measure Voltage [V]
uint8_t vi01_measure(uint32_t address, const uint8_t* channel, uint8_t channel_size, uint32_t samples, float frequency,
   float* voltage, uint32_t* voltage_size);

// Set Sampling Frequency [Hz]
uint8_t vi01_set_frequency(uint32_t address, uint16_t frequency);

// Stop Voltage Measurement or Calibration
uint8_t vi01_stop(uint32_t address);

// Control Voltage [V]
uint8_t vo01_control(uint32_t address, const uint8_t* channel, uint8_t channel_size, const float* voltage,
   uint8_t voltage_size);
